KeyBag

Struct KeyBag 

pub struct KeyBag { /* private fields */ }
Contains keys used for encrypting/decrypting data

Implementations

Source

impl KeyBag

pub fn new() -> Self

Makes an instance of KeyBag

pub fn from_string(string: &str) -> CytrynaResult<Self>

Makes an instance of KeyBag from a string in format compatible with keys returned by https://github.com/citra-emu/citra/raw/master/dist/dumpkeys/DumpKeys.gm9

Note that this script won’t dump all keys used in this library

pub fn set_key(&mut self, idx: KeyIndex, key: [u8; 16])

Adds a key to KeyBag, overwriting previous data if there was any

pub fn finalize(self)

Sets the KeyBag to be used for all crypto functions of this crate

pub fn get_key(&self, idx: KeyIndex) -> CytrynaResult<&[u8; 16]>

Returns a key if it is contained in global KeyBag instance

pub fn global() -> CytrynaResult<&'static Self>

Returns reference to the global KeyBag instance